==> haskell-tabular-0.2.2.7-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tabular.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tabular
version: 0.2.2.7
id: tabular-0.2.2.7-5b7MGmRWrPsD9aeDanGUHj
key: tabular-0.2.2.7-5b7MGmRWrPsD9aeDanGUHj
license: BSD3
maintainer: Eric Kow <eric.kow@gmail.com>
homepage: http://hub.darcs.net/kowey/tabular
synopsis: Two-dimensional data tables with rendering functions
description:
    Tabular provides a Haskell representation of two-dimensional
    data tables, the kind that you might find in a spreadsheet or
    or a research report.  It also comes with some default
    rendering functions for turning those tables into ASCII art,
    simple text with an arbitrary delimiter, CSV, HTML or LaTeX.
    .
    Below is an example of the kind of output this library produces.
    The tabular package can group rows and columns, each group
    having one of three separators (no line, single line, double line)
    between its members.
    .
    >     || memtest 1 | memtest 2 ||  time test  | time test 2
    > ====++===========+===========++=============+============
    > A 1 ||       hog |  terrible ||        slow |      slower
    > A 2 ||       pig |   not bad ||        fast |     slowest
    > ----++-----------+-----------++-------------+------------
    > B 1 ||      good |     awful || intolerable |    bearable
    > B 2 ||    better | no chance ||    crawling |     amazing
    > B 3 ||       meh |   well... ||  worst ever |          ok
category: Text
author: Eric Kow
exposed: True
indefinite: False
exposed-modules:
    Text.Tabular Text.Tabular.AsciiArt Text.Tabular.Csv
    Text.Tabular.Html Text.Tabular.Latex Text.Tabular.SimpleText
abi: 0afa087b5db75b06ce622fb82da2710e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tabular-0.2.2.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/tabular-0.2.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tabular-0.2.2.7
hs-libraries: HStabular-0.2.2.7-5b7MGmRWrPsD9aeDanGUHj
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    csv-0.1.2-DF8z6jUOfpiBCBTUDP7ddT
    html-1.0.1.2-HJx3nTTgwhH7I2VQDflUHM
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             csv-0.1.2-DF8z6jUOfpiBCBTUDP7ddT=c8be1ffd4ebf4503e020c87d7967bc83
             html-1.0.1.2-HJx3nTTgwhH7I2VQDflUHM=aa7e7bb2d474986fc227927ea5a6d356
haddock-interfaces: /usr/share/doc/haskell-tabular/html/tabular.haddock
haddock-html: /usr/share/doc/haskell-tabular/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tabular-0.2.2.7-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tabular.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tabular
version: 0.2.2.7
id: tabular-0.2.2.7-LDXOeo3eFKdD1roUxY5Euz
key: tabular-0.2.2.7-LDXOeo3eFKdD1roUxY5Euz
license: BSD3
maintainer: Eric Kow <eric.kow@gmail.com>
homepage: http://hub.darcs.net/kowey/tabular
synopsis: Two-dimensional data tables with rendering functions
description:
    Tabular provides a Haskell representation of two-dimensional
    data tables, the kind that you might find in a spreadsheet or
    or a research report.  It also comes with some default
    rendering functions for turning those tables into ASCII art,
    simple text with an arbitrary delimiter, CSV, HTML or LaTeX.
    .
    Below is an example of the kind of output this library produces.
    The tabular package can group rows and columns, each group
    having one of three separators (no line, single line, double line)
    between its members.
    .
    >     || memtest 1 | memtest 2 ||  time test  | time test 2
    > ====++===========+===========++=============+============
    > A 1 ||       hog |  terrible ||        slow |      slower
    > A 2 ||       pig |   not bad ||        fast |     slowest
    > ----++-----------+-----------++-------------+------------
    > B 1 ||      good |     awful || intolerable |    bearable
    > B 2 ||    better | no chance ||    crawling |     amazing
    > B 3 ||       meh |   well... ||  worst ever |          ok
category: Text
author: Eric Kow
exposed: True
indefinite: False
exposed-modules:
    Text.Tabular Text.Tabular.AsciiArt Text.Tabular.Csv
    Text.Tabular.Html Text.Tabular.Latex Text.Tabular.SimpleText
abi: 9eb5464416c8eb1db1c1573376165c09
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tabular-0.2.2.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/tabular-0.2.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tabular-0.2.2.7
hs-libraries: HStabular-0.2.2.7-LDXOeo3eFKdD1roUxY5Euz
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    csv-0.1.2-JHiDO18E4reI6zYI6iizmR
    html-1.0.1.2-HJx3nTTgwhH7I2VQDflUHM
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             csv-0.1.2-JHiDO18E4reI6zYI6iizmR=d778e46fa612889b3c689a57f9f2e321
             html-1.0.1.2-HJx3nTTgwhH7I2VQDflUHM=aa7e7bb2d474986fc227927ea5a6d356
haddock-interfaces: /usr/share/doc/haskell-tabular/html/tabular.haddock
haddock-html: /usr/share/doc/haskell-tabular/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
